@@ -49,8 +49,6 @@ class Invoice(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMix
         self.Balance = 0
         self.AllowIPNPayment = True
         self.DocNumber = ""
-        self.TxnDate = ""
-        self.TxnSource = ""
         self.PrivateNote = ""
         self.DueDate = ""
         self.ShipDate = ""
@@ -62,11 +60,14 @@ class Invoice(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMix
         self.ExchangeRate = 1
         self.GlobalTaxCalculation = "TaxExcluded"
 
+        self.EInvoiceStatus = None
+
         self.BillAddr = None
         self.ShipAddr = None
         self.BillEmail = None
         self.CustomerRef = None
         self.CurrencyRef = None
+        self.CustomerMemo = None
         self.DepartmentRef = None
         self.TxnTaxDetail = None
         self.DeliveryInfo = None
@@ -84,4 +85,11 @@ class Invoice(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMix
         linked_txn.TxnType = "Invoice"
         linked_txn.TxnLineId = 1
 
-        return linked_txn
\ No newline at end of file
+        return linked_txn
+
+    @property
+    def email_sent(self):
+        if self.EmailStatus == "EmailSent":
+            return True
+
+        return False
