@@ -1,5 +1,6 @@
 import unittest
 
+
 from quickbooks.objects.account import Account
 
 
@@ -8,7 +9,7 @@ class AccountTests(unittest.TestCase):
         account = Account()
         account.FullyQualifiedName = "test"
 
-        self.assertEquals(unicode(account), "test")
+        self.assertEquals(str(account), "test")
 
     def test_to_ref(self):
         account = Account()
